@@ -6,8 +6,6 @@ from modeller import model_topology, alignment
 from modeller import modfile, coordinates, alnsequence
 from modeller.atom_type import AtomType
 
-__docformat__ = "epytext en"
-
 class Atom(coordinates.Atom):
     """A single atom in a protein structure"""
 
@@ -79,6 +77,7 @@ class model(coordinates.Coordinates):
     env = None
     __gprsr = None
     _atom_class = Atom
+    __free_func = _modeller.mod_model_free
 
     def __init__(self, env, **vars):
         coordinates.Coordinates.__init__(self)
@@ -104,7 +103,7 @@ class model(coordinates.Coordinates):
 
     def __del__(self):
         if self.modpt:
-            _modeller.mod_model_free(self.modpt)
+            self.__free_func(self.modpt)
 
     def __repr__(self):
         return "Model containing %s, %s, and %s" \
@@ -125,16 +124,18 @@ class model(coordinates.Coordinates):
         return (range(1, self.natm+1), self)
 
     def read(self, file, model_format='PDB',
-             model_segment=('FIRST:@', 'LAST:'), io=None):
+             model_segment=('FIRST:@', 'LAST:'), io=None,
+             keep_disulfides=False):
         """Read coordinates from a file"""
         if io is None:
             io = self.env.io
         if isinstance(file, str):
             file = _modeller.mod_pdb_filename_get(file, io.atom_files_directory)
         fh = modfile._get_filehandle(file, 'r')
-        return _modeller.mod_model_read(self.modpt, io.modpt,
-                                        self.env.libs.modpt, fh.file_pointer,
-                                        model_format, model_segment)
+        return _modeller.mod_model_read2(self.modpt, io.modpt,
+                                         self.env.libs.modpt, fh.file_pointer,
+                                         model_format, model_segment,
+                                         keep_disulfides)
 
     def write(self, file, model_format='PDB', no_ter=False, extra_data=''):
         """Write coordinates to a file"""
@@ -194,7 +195,8 @@ class model(coordinates.Coordinates):
 
     def saxs_chifun(self, transfer_is, edat=None):
         """Calculate SAXS score from model.
-           @param transfer_is: if False: I(s) is not computed, i.e. the
+
+           :param transfer_is: if False: I(s) is not computed, i.e. the
                   intensity which is in memory is used
         """
         if edat is None:
